netapp_ontap.models.cifs_netbios API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.cifs_netbios`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class CifsNetbiosSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the CifsNetbios object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `aliases: List[str] GET POST PATCH`

    The aliases field of the cifs_netbios.

    Example: ["ALIAS_1","ALIAS_2","ALIAS_3"]

  `enabled: bool GET POST PATCH`

    Specifies whether NetBios name service (NBNS) is enabled for the CIFS. If this service is enabled, the CIFS server will start sending the broadcast for name registration.

  `wins_servers: List[str] GET POST PATCH`

    The wins_servers field of the cifs_netbios.

    Example: ["10.224.65.20","10.224.65.21"]